Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/python/dandeliion/client/__init__.py | 29 | 1 | 0 | 97%
src/python/dandeliion/client/exceptions.py | 4 | 0 | 0 | 100%
src/python/dandeliion/client/simulator.py | 53 | 2 | 0 | 96%
src/python/dandeliion/client/solution.py | 56 | 1 | 0 | 98%
src/python/dandeliion/client/tools/misc.py | 12 | 0 | 0 | 100%
src/python/dandeliion/client/websocket.py | 37 | 1 | 0 | 97%
Total | 191 | 5 | 0 | 97%

No items found using the specified filter.